@@ -90,23 +90,26 @@ dm <- function(..., .name_repair = c("check_unique", "unique", "universal", "min
 #' @rdname dm
 #' @export
 new_dm <- function(tables = list()) {
+  new_dm2(tables)
+}
+
+new_dm2 <- function(tables = list(),
+                    pks = structure(list(), names = character()),
+                    fks = structure(list(), names = character()),
+                    validate = TRUE) {
   # Legacy
   data <- unname(tables)
   table <- names2(tables)
+
+  stopifnot(!is.null(names(pks)), all(names(pks) %in% table))
+  stopifnot(!is.null(names(fks)), all(names(fks) %in% table))
+
   zoom <- new_zoom()
   col_tracker_zoom <- new_col_tracker_zoom()
 
-  pks <-
-    tibble(
-      table = table,
-      pks = list_of(new_pk())
-    )
+  pks_df <- enframe(pks, "table", "pks")
 
-  fks <-
-    tibble(
-      table = table,
-      fks = list_of(new_fk())
-    )
+  fks_df <- enframe(fks, "table", "fks")
 
   filters <-
     tibble(
@@ -116,13 +119,15 @@ new_dm <- function(tables = list()) {
 
   def <-
     tibble(table, data, segment = NA_character_, display = NA_character_) %>%
-    left_join(pks, by = "table") %>%
-    left_join(fks, by = "table") %>%
-    left_join(filters, by = "table") %>%
+    left_join(pks_df, by = "table") %>%
+    mutate(pks = as_list_of(map(pks, `%||%`, new_pk()), .ptype = new_pk())) %>%
+    left_join(fks_df, by = "table") %>%
+    mutate(fks = as_list_of(map(fks, `%||%`, new_fk()), .ptype = new_fk())) %>%
+    mutate(filters = list_of(new_filter())) %>%
     left_join(zoom, by = "table") %>%
     left_join(col_tracker_zoom, by = "table")
 
-  new_dm3(def, validate = FALSE)
+  new_dm3(def, validate = validate)
 }
 
 new_dm3 <- function(def, zoomed = FALSE, validate = TRUE) {
@@ -132,10 +137,8 @@ new_dm3 <- function(def, zoomed = FALSE, validate = TRUE) {
   )
   out <- structure(list(def = def), class = class, version = 1L)
 
-  # Enable for strict tests:
-  # if (validate) {
-  #   validate_dm(out)
-  # }
+  # Enable for strict tests (search for INSTRUMENT in .github/workflows):
+  # if (validate) { validate_dm(out) } # INSTRUMENT: validate
 
   out
 }
@@ -276,7 +279,7 @@ dm_get_zoom <- function(x, cols = c("table", "zoom"), quiet = FALSE) {
   # Performance
   def <- dm_get_def(x, quiet)
   zoom <- def$zoom
-  where <- which(lengths(zoom) != 0)
+  where <- which(!map_lgl(zoom, is.null))
   if (length(where) != 1) {
     # FIXME: Better error message?
     abort_not_pulling_multiple_zoomed()
@@ -745,3 +748,55 @@ as.list.dm <- function(x, ...) { # for both dm and zoomed_dm
 as.list.zoomed_dm <- function(x, ...) {
   as.list(tbl_zoomed(x))
 }
+
+#' @export
+glimpse.dm <- function(x, width = NULL, ...) {
+  glimpse_width <- if (is.null(width)) {
+    getOption("width")
+  } else {
+    width
+  }
+  table_list <- dm_get_tables_impl(x)
+  if (length(table_list) == 0) {
+    cat_line(trim_width("dm of 0 tables", glimpse_width))
+    return(invisible(x))
+  }
+  cat_line(
+    trim_width(
+      paste0("dm of ", length(table_list), " tables: ", toString(tick(names(table_list)))),
+      glimpse_width
+    )
+  )
+
+  all_fks <- dm_get_all_fks_impl(x)
+  iwalk(table_list, function(table, table_name) {
+    cat_line("\n", trim_width(paste0("Table: ", tick(table_name)), glimpse_width))
+    pk <- dm_get_pk_impl(x, table_name) %>%
+      map_chr(~ paste0("(", paste0(tick(.x), collapse = ", "), ")"))
+    if (!is_empty(pk)) {
+      # FIXME: needs to change if #622 is solved
+      cat_line(trim_width(paste0("Primary key: ", pk), glimpse_width))
+    }
+    fk <- all_fks %>%
+      filter(child_table == table_name) %>%
+      select(-child_table) %>%
+      pmap_chr(
+        function(child_fk_cols, parent_table, parent_key_cols) {
+          trim_width(
+            paste0(
+              "  (",
+              paste0(tick(child_fk_cols), collapse = ", "), ")",
+              " -> ",
+              paste0("(`", paste0(parent_table, "$", parent_key_cols, collapse = "`, `"), "`)")
+            ),
+            glimpse_width
+          )
+      })
+    if (!is_empty(fk)) {
+      cat_line(length(fk), " outgoing foreign key(s):")
+      cat_line(fk)
+    }
+    glimpse(table, width = width, ...)
+  })
+  invisible(x)
+}
