@@ -28,6 +28,7 @@ utils::globalVariables(c(
   "cols",
   "column",
   "columns",
+  "constraint",
   "day",
   "dest",
   "df",
@@ -40,16 +41,18 @@ utils::globalVariables(c(
   "into",
   "is_key",
   "key",
+  "key_fk",
   "col_tracker_zoom",
   "kind",
   "mismatch_or_null",
   "name",
+  "need_ref",
   "new_display",
   "new_name",
   "old",
   "origin",
   "parent",
-  "parent_pk_cols",
+  "parent_key_cols",
   "parent_table",
   "pk",
   "pk_col",
@@ -57,6 +60,7 @@ utils::globalVariables(c(
   "problem",
   "ref",
   "ref_col",
+  "ref_column",
   "ref_table",
   "remote_name",
   "renames",
