@@ -437,7 +437,14 @@ test_that("key tracking works", {
       summarize(g_list = list(g)) %>%
       dm_insert_zoomed("new_tbl") %>%
       get_all_keys()
+  })
+})
 
+test_that("key tracking works (2)", {
+  # https://github.com/tidyverse/dbplyr/issues/670
+  skip_if_remote_src()
+
+  expect_snapshot({
     "transmute()"
 
     # grouped by two key cols: "c" and "e" -> these two remain
@@ -445,13 +452,23 @@ test_that("key tracking works", {
       transmute(d_mean = mean(d)) %>%
       dm_insert_zoomed("new_tbl") %>%
       get_all_keys()
+  })
+})
 
+test_that("key tracking works (3)", {
+  # FKs that point to a PK that vanished, should also vanish
+  expect_snapshot({
     # grouped_by non-key col means, that no keys remain
     zoomed_grouped_in_dm %>%
       transmute(g_list = list(g)) %>%
       dm_insert_zoomed("new_tbl") %>%
       get_all_keys()
+  })
+})
 
+test_that("key tracking works (4)", {
+  # FKs that point to a PK that vanished, should also vanish
+  expect_snapshot({
     "mutate()"
 
     # grouped by two key cols: "c" and "e" -> these two remain
@@ -471,7 +488,13 @@ test_that("key tracking works", {
       mutate(g_new = list(g)) %>%
       dm_insert_zoomed("new_tbl") %>%
       get_all_keys()
+  })
+})
 
+test_that("key tracking works (5)", {
+  skip_if_remote_src()
+
+  expect_snapshot({
     "chain of renames & other transformations"
 
     zoomed_grouped_out_dm %>%
@@ -485,7 +508,7 @@ test_that("key tracking works", {
   })
 })
 
-test_that("key tracking works (2)", {
+test_that("key tracking works (6)", {
   # FKs that point to a PK that vanished, should also vanish
   expect_snapshot({
     zoomed_grouped_in_dm %>%
@@ -494,7 +517,7 @@ test_that("key tracking works (2)", {
   })
 })
 
-test_that("key tracking works (3)", {
+test_that("key tracking works for distinct() and arrange()", {
   expect_identical(
     zoomed_dm() %>%
       distinct(d_new = d) %>%
